AdaptiveTicketView class

A customizable ticket widget that creates a beautiful ticket view with dynamic content.

The AdaptiveTicketView widget provides a customizable ticket layout with:

  • Customizable background and border colors
  • Dynamic content area
  • Optional bottom message and ticket code
  • Customizable line style (none, dotted, or solid)

Example:

AdaptiveTicketView(
  ticketBgColor: Colors.blue[100]!,
  ticketBorderColor: Colors.blue,
  ticketInfoWidget: YourCustomContent(),
  ticketBottomMessage: "Enjoy your journey!",
  ticketCode: "123456789",
  lineStyle: TicketLineStyle.dotted,
)
Inheritance

Constructors

AdaptiveTicketView({Key? key, required Color ticketBorderColor, required Color ticketBgColor, Widget? ticketInfoWidget, String? ticketBottomMessage, String? ticketCode, TicketLineStyle lineStyle = TicketLineStyle.dotted, Color lineColor = const Color(0xff0077b6)})
Creates an AdaptiveTicketView widget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineColor Color
Color of the separator line
final
lineStyle TicketLineStyle
The style of the separator line
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticketBgColor Color
The background color of the ticket
final
ticketBorderColor Color
The border color of the ticket
final
ticketBottomMessage String?
Optional message to be displayed at the bottom of the ticket
final
ticketCode String?
Optional ticket code to be displayed at the bottom
final
ticketInfoWidget Widget?
The main content widget to be displayed in the ticket
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AdaptiveTicketView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited